#
# spec file for package cgal
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Ioda-Net Sàrl, Charmoille, Switzerland.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
#@TODO : clarify and split licence correctly, GPL & LGPL 3+ version
#@TODO : split package in coherent parts
#@TODO : rename parts (inspirated by sfcgal packaging)
#@TODO : ask for rename and take into account the obsolete existant thing. like libcgal deps
%define _soname 10
%define _soversion 10.0.4
%define _sourcename CGAL
%define _libname libCGAL%{_soname}
Name:           cgal
Version:        4.5.2
Release:        8.16
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0+ and LGPL-3.0+
Group:          Productivity/Graphics/CAD
Url:            http://www.cgal.org/
# You will need to update the magic numbers from the download urls on updating
Source0:        https://gforge.inria.fr/frs/download.php/file/34513/%{_sourcename}-%{version}.tar.xz
Patch0:         CMake-3.3.patch
Source1:        https://gforge.inria.fr/frs/download.php/file/34513/%{_sourcename}-%{version}-doc_html.tar.xz
Source2:        cgal-rpmlintrc
BuildRequires:  blas-devel
BuildRequires:  boost-devel >= 1.39
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glu-devel
BuildRequires:  gmp-devel
BuildRequires:  lapack-devel
BuildRequires:  libqt4-devel
BuildRequires:  mpfr-devel
BuildRequires:  xz
BuildRequires:  zlib-devel
Requires:       libcgal-devel = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
CGAL is a collaborative effort of several sites in Europe and
Israel. The goal is to make the most important of the solutions and
methods developed in computational geometry available to users in
industry and academia in a C++ library. The goal is to provide easy
access to useful, reliable geometric algorithms.

CGAL is used in various areas needing geometric computation, such as:
computer graphics, scientific visualization, computer aided design
and modeling, geographic information systems, molecular biology,
medical imaging, robotics and motion planning, mesh generation,
numerical methods.

%package -n %{_libname}
Summary:        Computational Geometry Algorithms Library
License:        GPL-3.0+ and LGPL-3.0+
Group:          System/Libraries

%description -n %{_libname}
Libraries for CGAL applications.
CGAL is a collaborative effort of several sites in Europe and
Israel. The goal is to make the most important of the solutions and
methods developed in computational geometry available to users in
industry and academia in a C++ library. The goal is to provide easy
access to useful, reliable geometric algorithms.

%package devel
Summary:        Development files and tools for CGAL applications
License:        GPL-3.0+ and LGPL-3.0+ and BSL-1.0
Group:          Development/Libraries
Requires:       %{_libname} = %{version}
Requires:       blas
Requires:       boost-devel
Requires:       cmake
Requires:       gmp-devel
Requires:       lapack
Requires:       mpfr-devel
Requires:       qt-devel
Requires:       zlib-devel
#For compatibility with package looking for our old name
Provides:       libcgal-devel = %{version}

%description devel
This package provides the headers files and tools you may need to
develop applications using CGAL.

%package demo-examples-devel
Summary:        Example & demo files for CGAL library usage
License:        GPL-3.0+ and LGPL-3.0+ and BSL-1.0 and MIT
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}
BuildArch:      noarch

%description demo-examples-devel
This package provides the sources of examples and demos of
CGAL algorithms. You can study them, compile and test CGAL
library.

%package doc
Summary:        Documentation CGAL algorithms
License:        GPL-3.0+ and LGPL-3.0+
Group:          Documentation/HTML
BuildArch:      noarch

%description doc
This package provides the documentation for CGAL algorithms.

%prep
%setup -q -n CGAL-%{version}
%patch0 -p1
tar -xJf %{SOURCE1}

%build
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
export CFLAGS="%{optflags} -fPIE -pie"
export CXXFLAGS="%{optflags} -fPIE -pie"
%cmake \
	-DCGAL_INSTALL_LIB_DIR=%{_lib} \
	-DCMAKE_BUILD_TYPE=Release \

make %{?_smp_mflags}

# Unfortunately take +6600sec locally.
# So we just deliver the source code in cgal package.
#  -DWITH_examples=true \
#  -DWITH_demos=true \

%install
%cmake_install

install -d %{buildroot}/%{_datadir}/CGAL/examples
install -d %{buildroot}/%{_datadir}/CGAL/demo
cp -a examples/* %{buildroot}/%{_datadir}/CGAL/examples
cp -a demo/* %{buildroot}/%{_datadir}/CGAL/demo

# Clean doc wrongly placed by make install
rm -rfv %{buildroot}/%{_datadir}/doc/CGAL-%{version}

# no macos here.
rm %{buildroot}/%{_bindir}/cgal_make_macosx_app

%fdupes doc_html
%fdupes %{buildroot}/%{_datadir}

%post -n %{_libname} -p /sbin/ldconfig

%postun -n %{_libname} -p /sbin/ldconfig

%files -n %{_libname}
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE*
%{_libdir}/libCGAL.so.%{_soversion}
%{_libdir}/libCGAL.so.%{_soname}
%{_libdir}/libCGAL_Core.so.%{_soversion}
%{_libdir}/libCGAL_Core.so.%{_soname}
%{_libdir}/libCGAL_ImageIO.so.%{_soversion}
%{_libdir}/libCGAL_ImageIO.so.%{_soname}
%{_libdir}/libCGAL_Qt4.so.%{_soversion}
%{_libdir}/libCGAL_Qt4.so.%{_soname}

%files devel
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE*
%{_includedir}/CGAL
%{_libdir}/libCGAL.so
%{_libdir}/libCGAL_Core.so
%{_libdir}/libCGAL_ImageIO.so
%{_libdir}/libCGAL_Qt4.so
%{_libdir}/CGAL
%{_bindir}/*
%{_mandir}/man1/cgal_create_cmake_script.1*

%files demo-examples-devel
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE*
%{_datadir}/CGAL

%files doc
%defattr(-,root,root,-)
%doc AUTHORS CHANGES LICENSE*
%doc doc_html

%changelog
* Thu Sep  3 2015 eric.fintzel@linux.vnet.ibm.com
- Build with CMake 3.3 (patch file CMake-3.3.patch).
* Sat Feb 28 2015 mpluskal@suse.com
- Remove conditionals and use only cmake macros for building
* Sat Feb 28 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Remove sha256sum.txt
- Update to 4.5.2
  * Fix a bug that prevented the compilation with recent versions
    of Boost (>=1.56) when explicit conversions operators
    (from C++11) are supported. That prevented the compilation with
    Microsoft Visual Studio 2013.
  * 3D Convex Hulls: Fix a non-robust predicate bug that was
    showing up when input points where lexicographically sorted.
  * 3D Mesh Generation: Fix a bug in the sliver perturbation
    optimization method. It could create some holes on the
    surface of the mesh.
* Thu Dec 25 2014 p.drouand@gmail.com
- Update to version 4.5.1,http://www.cgal.org/releases.html#release4.5.1
- Bump sover to 10.0.4
* Tue Jun  3 2014 bruno@ioda-net.ch
- update to 4.4, see http://www.cgal.org/releases.html#release4.4
- packaging : remove libcgal%%soname as main package
- cgal is dumb empty package
- libcgalsoname contain only library
- cgal-demo-examples-devel contain all demo and example
- cgal-doc contain the whole documentation
- Fix & cleanup Licence as specified in sources
- Make it build for SLE with exception for noarch.
* Tue Dec 17 2013 coolo@suse.com
- update to 4.3, see http://www.cgal.org/releases.html#release4.3
* Sat Jan 19 2013 prusnak@opensuse.org
- updated to 4.1
* Fri Aug  3 2012 jw@suse.com
- added happy_gcc.patch
  fixed c++ syntax for a more strict gcc
* Fri Aug  3 2012 jw@suse.com
- fixed Group and License
* Fri Aug  3 2012 jw@suse.com
- added boost149workaround.patch
* Sun Jan  8 2012 prusnak@opensuse.org
- updated to 3.9
* Sat May 14 2011 prusnak@opensuse.org
- don't build Qt3 library anymore
- use fdupes
* Fri May 13 2011 prusnak@opensuse.org
- based on a Fedora package by Laurent Rineau (version 3.8)
